#
# Configuration file for using the xslt library
#
XSLT_LIBDIR="-LFIXMESTAGINGDIRHOST/usr/lib"
XSLT_LIBS="-lxslt -LFIXMESTAGINGDIRHOST/usr/lib/pkgconfig/../../../usr/lib -lxml2 "
XSLT_PRIVATE_LIBS="-lm"
XSLT_INCLUDEDIR="-IFIXMESTAGINGDIRHOST/usr/include"
MODULE_VERSION="xslt-1.1.35"
